@@ -8,7 +8,7 @@ def run_article_md_daily_notes(
     input_file_names: list[str],
     path_output_file: str,
     bib_path_or_file: str,
-    path_conferences_journals_json: str,
+    path_conf_j_jsons: str,
     options: dict
 ) -> None:
     """
@@ -19,7 +19,7 @@ def run_article_md_daily_notes(
         input_file_names (list[str]): List of input file names
         path_output_file (str): Path to output directory
         bib_path_or_file (str): Path to bibliography file or directory
-        path_conferences_journals_json (str): Path to conferences and journals JSON files directory
+        path_conf_j_jsons (str): Path to conferences and journals JSON files directory
         options (dict): Additional options to override default settings
 
     Returns:
@@ -30,8 +30,8 @@ def run_article_md_daily_notes(
 
     # Initialize default options with detailed descriptions
     _options = {
-        "full_json_c": os.path.expanduser(os.path.join(path_conferences_journals_json, "conferences.json")),
-        "full_json_j": os.path.expanduser(os.path.join(path_conferences_journals_json, "journals.json")),
+        "full_json_c": os.path.expanduser(os.path.join(path_conf_j_jsons, "conferences.json")),
+        "full_json_j": os.path.expanduser(os.path.join(path_conf_j_jsons, "journals.json")),
 
         # figure options
         "includegraphics_figs_directory": "",
@@ -68,9 +68,12 @@ def run_article_md_daily_notes(
         "generate_tex": False,
 
         # md options
+        # ["www", "google", "connected", "scite"]
+        "display_www_google_connected_scite": ["google", "connected"],  # python_writers.py
+
         "add_url_for_basic_dict": False,  # default is True
-        "add_anchor_for_basic_dict": False,  # default is False
-        "add_anchor_for_beauty_dict": True,  # default is False
+        "add_anchor_for_basic_dict": True,  # default is False
+        "add_anchor_for_beauty_dict": False,  # default is False
         "add_anchor_for_complex_dict": False,  # default is False
 
         "final_output_main_md_name": "main.md",
@@ -78,8 +81,8 @@ def run_article_md_daily_notes(
         "add_reference_in_md": True,
         "add_bib_in_md": False,
         "replace_cite_to_fullcite_in_md": True,
-        "replace_by_basic_beauty_complex_in_md": "basic",
-        "display_basic_beauty_complex_references_in_md": "beauty",
+        "replace_by_basic_beauty_complex_in_md": "beauty",  # default is "basic"
+        "display_basic_beauty_complex_references_in_md": "basic",  # default is "beauty"
         "add_anchor_in_md": True,  # default is False
 
         "md_folder_name": "mds",  # "" or "md" or "main"
